Administer - Advanced, free open-soruce admin panel

1.1.1 out now!

# Simple & open administration

Welcome to Administer, the admin panel that's fully yours.

Get on Roblox Documentation

## Why Administer?

With so many administration solutions on Roblox currently, choosing which one is right for your game is tough. Thankfully, Administer is perfect for almost all use cases. You can also refer to the handy guide we have.

### Lightweight

Administer fully starts up and listens to requests in just .3 seconds, with a frontend that's quick and easy for admins to use.

### Customizable

Administer is highly customizable in terms of how admins and the panel works. You can change anything you could ever want.

### Modular

You are free to remove and add apps to fit your game's exact needs. Zero bloat.

# An app for everything.

On Administer, instead of one central module which controls everything, you get apps which individually act as groups of commands, such as Player Management, Soft Shutdown Pro, or Global Announcements.